==> haskell-mysql-0.2.0.1-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mysql.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mysql
version:              0.2.0.1
visibility:           public
id:                   mysql-0.2.0.1-34YofSvuu3CI6EzF1EIQwM
key:                  mysql-0.2.0.1-34YofSvuu3CI6EzF1EIQwM
license:              BSD-3-Clause
copyright:
    Copyright 2011 MailRank, Inc.
    Copyright 2013 Bryan O'\''Sullivan <bos@serpentine.com>

maintainer:           Paul Rouse <pyr@doynton.org>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/paul-rouse/mysql
synopsis:             A low-level MySQL client library.
description:
    A low-level client library for the MySQL database, implemented as
    bindings to the C @mysqlclient@ API.

    /Important licensing note/: This library is BSD-licensed under the
    terms of the MySQL FOSS License Exception
    <http://www.mysql.com/about/legal/licensing/foss-exception/>.

    Since this library links against the GPL-licensed @mysqlclient@
    library, a non-open-source application that uses it /may/ be
    subject to the terms of the GPL.

category:             Database
abi:                  039e1c84313f3076ea725747712c7a02
exposed:              True
exposed-modules:
    Database.MySQL.Base Database.MySQL.Base.C Database.MySQL.Base.Types

import-dirs:          /usr/lib/ghc-8.10.4/site-local/mysql-0.2.0.1
library-dirs:
    /usr/lib/ghc-8.10.4/site-local/mysql-0.2.0.1 /usr/lib/

dynamic-library-dirs: /usr/lib /usr/lib/
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/mysql-0.2.0.1
hs-libraries:         HSmysql-0.2.0.1-34YofSvuu3CI6EzF1EIQwM
extra-libraries:      dl m pthread ssl crypto mariadb
include-dirs:         /usr/include/mysql /usr/include/mysql/mysql
depends:              base-4.14.1.0 bytestring-0.10.12.0 containers-0.6.2.1
haddock-interfaces:   /usr/share/doc/haskell-mysql/html/mysql.haddock
haddock-html:         /usr/share/doc/haskell-mysql/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mysql-0.2.0.1-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mysql.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mysql
version:              0.2.0.1
visibility:           public
id:                   mysql-0.2.0.1-EwXxAotS1Dq1HHhod8Waip
key:                  mysql-0.2.0.1-EwXxAotS1Dq1HHhod8Waip
license:              BSD-3-Clause
copyright:
    Copyright 2011 MailRank, Inc.
    Copyright 2013 Bryan O'\''Sullivan <bos@serpentine.com>

maintainer:           Paul Rouse <pyr@doynton.org>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/paul-rouse/mysql
synopsis:             A low-level MySQL client library.
description:
    A low-level client library for the MySQL database, implemented as
    bindings to the C @mysqlclient@ API.

    /Important licensing note/: This library is BSD-licensed under the
    terms of the MySQL FOSS License Exception
    <http://www.mysql.com/about/legal/licensing/foss-exception/>.

    Since this library links against the GPL-licensed @mysqlclient@
    library, a non-open-source application that uses it /may/ be
    subject to the terms of the GPL.

category:             Database
abi:                  2fa7f2a0912df82dbb2c8fb8935b0f13
exposed:              True
exposed-modules:
    Database.MySQL.Base Database.MySQL.Base.C Database.MySQL.Base.Types

import-dirs:          /usr/lib/ghc-8.10.4/site-local/mysql-0.2.0.1
library-dirs:
    /usr/lib/ghc-8.10.4/site-local/mysql-0.2.0.1 /usr/lib/

dynamic-library-dirs: /usr/lib /usr/lib/
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/mysql-0.2.0.1
hs-libraries:         HSmysql-0.2.0.1-EwXxAotS1Dq1HHhod8Waip
extra-libraries:      dl m pthread ssl crypto mariadb
include-dirs:         /usr/include/mysql /usr/include/mysql/mysql
depends:              base-4.14.1.0 bytestring-0.10.12.0 containers-0.6.2.1
haddock-interfaces:   /usr/share/doc/haskell-mysql/html/mysql.haddock
haddock-html:         /usr/share/doc/haskell-mysql/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
